@@ -23,16 +23,16 @@ static const char configKeyDefaultIdentity[] = "Default Identity";
 #include "identitymanager.h"
 #include "identity.h" // for IdentityList::{export,import}Data
 
-#include <kemailaddress.h> // for static helper functions
+#include <KEmailAddress> // for static helper functions
 
-#include <kemailsettings.h> // for IdentityEntry::fromControlCenter()
-#include <klocalizedstring.h>
+#include <KEMailSettings> // for IdentityEntry::fromControlCenter()
+#include <KLocalizedString>
 #include "kidentitymanagement_debug.h"
-#include <kconfig.h>
-#include <ksharedconfig.h>
+#include <KConfig>
+#include <KSharedConfig>
 #include <kuser.h>
-#include <kconfiggroup.h>
-#include <kdelibs4configmigrator.h>
+#include <KConfigGroup>
+#include <Kdelibs4ConfigMigrator>
 
 #include <QList>
 #include <QHostInfo>
@@ -40,7 +40,7 @@ static const char configKeyDefaultIdentity[] = "Default Identity";
 
 #include <QRegularExpression>
 #include <assert.h>
-#include <krandom.h>
+#include <KRandom>
 
 #include "identitymanageradaptor.h"
 
@@ -568,7 +568,12 @@ Identity &IdentityManager::modifyIdentityForName(const QString &name)
 
     qCWarning(KIDENTITYMANAGEMENT_LOG) << "IdentityManager::modifyIdentityForName() used as"
                                        << "newFromScratch() replacement!"
-                                       << endl << "  name == \"" << name << "\"";
+                                      #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+                                       << endl
+                                      #else
+                                       << Qt::endl
+                                      #endif
+                                       << "  name == \"" << name << "\"";
     return newFromScratch(name);
 }
 
@@ -582,7 +587,12 @@ Identity &IdentityManager::modifyIdentityForUoid(uint uoid)
 
     qCWarning(KIDENTITYMANAGEMENT_LOG) << "IdentityManager::identityForUoid() used as"
                                        << "newFromScratch() replacement!"
-                                       << endl << "  uoid == \"" << uoid << "\"";
+                                      #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+                                       << endl
+                                      #else
+                                       << Qt::endl
+                                      #endif
+                                       << "  uoid == \"" << uoid << "\"";
     return newFromScratch(i18n("Unnamed"));
 }
 
